Barcode class

General Barcode model, the maom instrument what you will use

Constructors

Barcode({required int? country, required int? company, required int? product, required String? barcode, required int? checkSum})
You can manual create your barcode model with input required fields country, company,product,barcode,checkSum
Barcode.parsBarcode({required String barcode})
The most easy way to pars your Barcode just put you barcode as value and you will get all what you need

Properties

barcode ↔ String?
getter/setter pair
checkSum ↔ int?
getter/setter pair
company ↔ int?
getter/setter pair
country ↔ int?
getter/setter pair
countryFlagCode → dynamic
After initialize your Barcode with our lib, now you can easy get country Flag code
no setter
countryName → dynamic
After initialize your Barcode with our lib, now you can easy get country Name
no setter
hashCode → int
The hash code for this object.
no setterinherited
product ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited